@@ -1,6 +1,6 @@
 <?php
-/*
- *  $Id: 939a70de13c353c815587a777c6502f6463eb3ad $
+/**
+ *  $Id: b20e9c95f1db91e9c0ec65ff977bfb22f0308601 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -23,10 +23,10 @@
  * BuildException is for when things go wrong in a build execution.
  *
  * @author   Andreas Aderhold <andi@binarycloud.com>
- * @version  $Id: 939a70de13c353c815587a777c6502f6463eb3ad $
+ * @version  $Id: b20e9c95f1db91e9c0ec65ff977bfb22f0308601 $
  * @package  phing
  */
-class BuildException extends Exception
+class BuildException extends RuntimeException
 {
 
     /**
@@ -54,7 +54,7 @@ class BuildException extends Exception
      * @param Location|Exception|null $p2
      * @param Location|null           $p3
      */
-    public function __construct($p1, $p2 = null, $p3 = null)
+    public function __construct($p1 = "", $p2 = null, $p3 = null)
     {
 
         $cause = null;
@@ -126,5 +126,4 @@ class BuildException extends Exception
         $this->location = $loc;
         $this->message = $loc->toString() . ': ' . $this->message;
     }
-
 }
