@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: af7509719aa6a6d1276e8640587764ccd9e5baf2 $
+ *  $Id: d9f9c7c8c60770d322683735f1aa5f45679c1381 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -38,7 +38,7 @@ include_once 'phing/parser/CustomChildCreator.php';
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: af7509719aa6a6d1276e8640587764ccd9e5baf2 $
+ * @version   $Id: d9f9c7c8c60770d322683735f1aa5f45679c1381 $
  * @package   phing
  */
 class IntrospectionHelper
@@ -229,11 +229,7 @@ class IntrospectionHelper
                         );
                     }
 
-                    $classname = null;
-
-                    if (($hint = $params[0]->getClass()) !== null) {
-                        $classname = $hint->getName();
-                    }
+                    $classname = $this->getClassNameFromParameter($params[0]);
 
                     if ($classname === null) {
                         throw new BuildException($method->getDeclaringClass()->getName() . "::" . $method->getName(
@@ -262,11 +258,7 @@ class IntrospectionHelper
                         );
                     }
 
-                    $classname = null;
-
-                    if (($hint = $params[0]->getClass()) !== null) {
-                        $classname = $hint->getName();
-                    }
+                    $classname = $this->getClassNameFromParameter($params[0]);
 
                     // we don't use the classname here, but we need to make sure it exists before
                     // we later try to instantiate a non-existent class
@@ -348,11 +340,7 @@ class IntrospectionHelper
                 // pass a project-relative file.
                 $params = $method->getParameters();
 
-                $classname = null;
-
-                if (($hint = $params[0]->getClass()) !== null) {
-                    $classname = $hint->getName();
-                }
+                $classname = $this->getClassNameFromParameter($params[0]);
 
                 // there should only be one param; we'll just assume ....
                 if ($classname !== null) {
@@ -458,11 +446,7 @@ class IntrospectionHelper
                 // exist and that method is using class hints
                 $params = $method->getParameters();
 
-                $classname = null;
-
-                if (($hint = $params[0]->getClass()) !== null) {
-                    $classname = $hint->getName();
-                }
+                $classname = $this->getClassNameFromParameter($params[0]);
 
                 // create a new instance of the object and add it via $addMethod
                 $clazz = new ReflectionClass($classname);
@@ -661,4 +645,23 @@ class IntrospectionHelper
         }
     }
 
+    /**
+     * @param ReflectionParameter $param
+     * @return string|null
+     */
+    private function getClassNameFromParameter(ReflectionParameter $param)
+    {
+        $classname = null;
+        if (version_compare(phpversion(), '7.0.0', '>=')) {
+            /** @var \ReflectionType $hint */
+            $classname = (($hint = $param->getType()) && !$hint->isBuiltin()) ? $hint->getName() : null;
+        } else {
+            if (($hint = $param->getClass()) !== null) {
+                $classname = $hint->getName();
+            }
+        }
+
+        return $classname;
+    }
+
 }
