@@ -1371,7 +1371,7 @@ class Phing
         // This is a bit of a hack, but works better than previous solution of assuming
         // data_dir is on the include_path.
         $dataDir = '@DATA-DIR@';
-        if ($dataDir{0} != '@') { // if we're using PEAR then the @ DATA-DIR @ token will have been substituted.
+        if ($dataDir[0] != '@') { // if we're using PEAR then the @ DATA-DIR @ token will have been substituted.
             if (!file_exists($dataDir)) {
                 self::log("The PEAR data_dir setting is incorrect: {$dataDir}.", Project::MSG_ERR);
                 self::log("Please edit using 'pear config-set data_dir ...' and re-install Phing.", Project::MSG_ERR);
