@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: eccc8da05ad1fbe73d38da7fca7ecb4816beabd0 $
+ * $Id: 0b4b3d0fd8890b49d3227fd5e46435264bb2f7ef $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -95,7 +95,7 @@ include_once 'phing/system/util/Properties.php';
  * @author     Hans Lellelid <hans@xmpl.org> (Phing)
  * @author     Magesh Umasankar (Ant)
  * @package    phing.listener
- * @version    $Id: eccc8da05ad1fbe73d38da7fca7ecb4816beabd0 $
+ * @version    $Id: 0b4b3d0fd8890b49d3227fd5e46435264bb2f7ef $
  */
 class AnsiColorLogger extends DefaultLogger
 {
@@ -157,7 +157,7 @@ class AnsiColorLogger extends DefaultLogger
      * Set the colors to use from a property file specified by the
      * special ant property ant.logger.defaults
      */
-    final private function setColors()
+    private function setColors()
     {
 
         $userColorFile = Phing::getProperty("phing.logger.defaults");
