@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 25f84e8447739435ac449a31307150bd6d8ea62a $
+ *  $Id: 00d84fa0e8e47909d6ffeb5ee12ce7febd2e73a8 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ include_once 'phing/BuildEvent.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: 25f84e8447739435ac449a31307150bd6d8ea62a $
+ * @version   $Id: 00d84fa0e8e47909d6ffeb5ee12ce7febd2e73a8 $
  * @see       BuildEvent
  * @package   phing.listener
  */
@@ -312,10 +312,10 @@ class DefaultLogger implements StreamRequiredBuildLogger
                 $minutes,
                 ($minutes === 1 ? " " : "s "),
                 $seconds - floor($seconds / 60) * 60,
-                ($seconds % 60 === 1 ? "" : "s")
+                (intval($seconds) % 60 === 1 ? "" : "s")
             );
         } else {
-            return sprintf("%0.4f second%s", $seconds, ($seconds % 60 === 1 ? "" : "s"));
+            return sprintf("%0.4f second%s", $seconds, (intval($seconds) % 60 === 1 ? "" : "s"));
         }
     }
 
