@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: 5288eb0042a1c3bf2b1d34ed509a6c46adce87fd $
+ * $Id: f12d493e0ab0e5d80102681147e2749fe12c238b $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -47,7 +47,7 @@ include_once 'phing/system/util/Properties.php';
  * @author     Hans Lellelid <hans@xmpl.org> (Phing Ansi Color Logger)
  * @author     Magesh Umasankar (Ant)
  * @package    phing.listener
- * @version    $Id: 5288eb0042a1c3bf2b1d34ed509a6c46adce87fd $
+ * @version    $Id: f12d493e0ab0e5d80102681147e2749fe12c238b $
  */
 class HtmlColorLogger extends DefaultLogger
 {
@@ -88,7 +88,7 @@ class HtmlColorLogger extends DefaultLogger
      * Set the colors to use from a property file specified in the
      * special phing property file "phing/listener/defaults.properties".
      */
-    final private function setColors()
+    private function setColors()
     {
 
         $systemColorFile = new PhingFile(Phing::getResourcePath("phing/listener/defaults.properties"));
