@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: b4ab57d15c992c322afd64f4376e36f526021a5d $
+ *  $Id: feed38557f156bd1c61593a048f37c2e246faf87 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -24,7 +24,7 @@
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: b4ab57d15c992c322afd64f4376e36f526021a5d $
+ * @version   $Id: feed38557f156bd1c61593a048f37c2e246faf87 $
  * @package   phing.parser
  */
 
@@ -42,7 +42,7 @@ class Location
      * @param  integer the line number
      * @param  integer the column number
      */
-    public function Location($fileName = null, $lineNumber = null, $columnNumber = null)
+    public function __construct($fileName = null, $lineNumber = null, $columnNumber = null)
     {
         $this->fileName = $fileName;
         $this->lineNumber = $lineNumber;
