@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 8a019e4034b2236c19058ea849b12fb88d3e2f43 $
+ *  $Id: 6332c0926e183bd18739ccc50aa58e4d79eb984f $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -16,7 +16,7 @@
  *
  * This software consists of voluntary contributions made by many individuals
  * and is licensed under the LGPL. For more information please see
- * <http://phing.info>. 
+ * <http://phing.info>.
  */
 
 /**
@@ -24,4 +24,6 @@
  *
  * @package   phing.system.io
  */
-class IOException extends Exception {}
+class IOException extends Exception
+{
+}
