@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 1ef78a7a6b9b116ebb4ec53c39f716f3ce1877e7 $
+ *  $Id: bbfa8fd9a50e3d77391499a47b22615dcca56e67 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -68,7 +68,7 @@ class Win32FileSystem extends FileSystem
      */
     public function slashify($p)
     {
-        if ((strlen($p) > 0) && ($p{0} != $this->slash)) {
+        if ((strlen($p) > 0) && ($p[0] != $this->slash)) {
             return $this->slash . $p;
         } else {
             return $p;
@@ -113,13 +113,13 @@ class Win32FileSystem extends FileSystem
     public function normalizePrefix($strPath, $len, &$sb)
     {
         $src = 0;
-        while (($src < $len) && $this->isSlash($strPath{$src})) {
+        while (($src < $len) && $this->isSlash($strPath[$src])) {
             $src++;
         }
         $c = "";
         if (($len - $src >= 2)
-            && $this->isLetter($c = $strPath{$src})
-            && $strPath{$src + 1} === ':'
+            && $this->isLetter($c = $strPath[$src])
+            && $strPath[$src + 1] === ':'
         ) {
             /* Remove leading slashes if followed by drive specifier.
              * This hack is necessary to support file URLs containing drive
@@ -131,8 +131,8 @@ class Win32FileSystem extends FileSystem
         } else {
             $src = 0;
             if (($len >= 2)
-                && $this->isSlash($strPath{0})
-                && $this->isSlash($strPath{1})
+                && $this->isSlash($strPath[0])
+                && $this->isSlash($strPath[1])
             ) {
                 /* UNC pathname: Retain first slash; leave src pointed at
                  * second slash so that further slashes will be collapsed
@@ -178,15 +178,15 @@ class Win32FileSystem extends FileSystem
         // Remove redundant slashes from the remainder of the path, forcing all
         // slashes into the preferred slash
         while ($src < $len) {
-            $c = $strPath{$src++};
+            $c = $strPath[$src++];
             if ($this->isSlash($c)) {
-                while (($src < $len) && $this->isSlash($strPath{$src})) {
+                while (($src < $len) && $this->isSlash($strPath[$src])) {
                     $src++;
                 }
                 if ($src === $len) {
                     /* Check for trailing separator */
                     $sn = (int) strlen($sb);
-                    if (($sn == 2) && ($sb{1} === ':')) {
+                    if (($sn == 2) && ($sb[1] === ':')) {
                         // "z:\\"
                         $sb .= $slash;
                         break;
@@ -196,7 +196,7 @@ class Win32FileSystem extends FileSystem
                         $sb .= $slash;
                         break;
                     }
-                    if (($sn === 1) && ($this->isSlash($sb{0}))) {
+                    if (($sn === 1) && ($this->isSlash($sb[0]))) {
                         /* "\\\\" is not collapsed to "\\" because "\\\\" marks
                         the beginning of a UNC pathname.  Even though it is
                         not, by itself, a valid UNC pathname, we leave it as
@@ -242,7 +242,7 @@ class Win32FileSystem extends FileSystem
         $altSlash = $this->altSlash;
         $prev = 0;
         for ($i = 0; $i < $n; $i++) {
-            $c = $strPath{$i};
+            $c = $strPath[$i];
             if ($c === $altSlash) {
                 return $this->normalizer($strPath, $n, ($prev === $slash) ? $i - 1 : $i);
             }
@@ -277,8 +277,8 @@ class Win32FileSystem extends FileSystem
         if ($n === 0) {
             return 0;
         }
-        $c0 = $path{0};
-        $c1 = ($n > 1) ? $path{1} :
+        $c0 = $path[0];
+        $c1 = ($n > 1) ? $path[1] :
             0;
         if ($c0 === $slash) {
             if ($c1 === $slash) {
@@ -289,7 +289,7 @@ class Win32FileSystem extends FileSystem
         }
 
         if ($this->isLetter($c0) && ($c1 === ':')) {
-            if (($n > 2) && ($path{2}) === $slash) {
+            if (($n > 2) && ($path[2]) === $slash) {
                 return 3; // Absolute local pathname "z:\\foo" */
             }
 
@@ -320,8 +320,8 @@ class Win32FileSystem extends FileSystem
         }
 
         $c = $child;
-        if (($cn > 1) && ($c{0} === $slash)) {
-            if ($c{1} === $slash) {
+        if (($cn > 1) && ($c[0] === $slash)) {
+            if ($c[1] === $slash) {
                 // drop prefix when child is a UNC pathname
                 $c = substr($c, 2);
             } else {
@@ -331,7 +331,7 @@ class Win32FileSystem extends FileSystem
         }
 
         $p = $parent;
-        if ($p{$pn - 1} === $slash) {
+        if ($p[$pn - 1] === $slash) {
             $p = substr($p, 0, $pn - 1);
         }
 
@@ -353,7 +353,7 @@ class Win32FileSystem extends FileSystem
     public function fromURIPath($strPath)
     {
         $p = (string) $strPath;
-        if ((strlen($p) > 2) && ($p{2} === ':')) {
+        if ((strlen($p) > 2) && ($p[2] === ':')) {
 
             // "/c:/foo" --> "c:/foo"
             $p = substr($p, 1);
@@ -381,7 +381,7 @@ class Win32FileSystem extends FileSystem
         $pl = (int) $f->getPrefixLength();
         $p = (string) $f->getPath();
 
-        return ((($pl === 2) && ($p{0} === $this->slash)) || ($pl === 3) || ($pl === 1 && $p{0} === $this->slash));
+        return ((($pl === 2) && ($p[0] === $this->slash)) || ($pl === 3) || ($pl === 1 && $p[0] === $this->slash));
     }
 
     /** private
@@ -390,7 +390,7 @@ class Win32FileSystem extends FileSystem
      */
     public function _driveIndex($d)
     {
-        $d = (string) $d{0};
+        $d = (string) $d[0];
         if ((ord($d) >= ord('a')) && (ord($d) <= ord('z'))) {
             return ord($d) - ord('a');
         }
@@ -416,7 +416,7 @@ class Win32FileSystem extends FileSystem
      */
     public function _getDriveDirectory($drive)
     {
-        $drive = (string) $drive{0};
+        $drive = (string) $drive[0];
         $i = (int) $this->_driveIndex($drive);
         if ($i < 0) {
             return null;
@@ -463,7 +463,7 @@ class Win32FileSystem extends FileSystem
         $path = $f->getPath();
         $pl = (int) $f->getPrefixLength();
 
-        if (($pl === 2) && ($path{0} === $this->slash)) {
+        if (($pl === 2) && ($path[0] === $this->slash)) {
             return $path; // UNC
         }
 
@@ -495,7 +495,7 @@ class Win32FileSystem extends FileSystem
             if (($ud !== null) && StringHelper::startsWith($ud, $path)) {
                 return (string) ($up . $this->slashify(substr($path, 2)));
             }
-            $drive = (string) $path{0};
+            $drive = (string) $path[0];
             $dir = (string) $this->_getDriveDirectory($drive);
 
             $np = (string) "";
