@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: b5edc38a7438b81c032898ccf3c2be0e83d55203 $
+ *  $Id: 203d7f55e3f1c0a9fc19a0603648ef688cfa68ae $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -20,7 +20,8 @@
  */
 
 /**
- *  @package   phing.system.lang
+ * @package   phing.system.lang
  */
-class FileNotFoundException extends Exception {}
-
+class FileNotFoundException extends Exception
+{
+}
