@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: e35435d78a6eca384d1c6735565077868b265778 $
+ *  $Id: 11ecf61bf1d7f534232f2394df745ee147f2b9b7 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -74,7 +74,7 @@ include_once 'phing/types/FileSet.php';
  *
  * @author   Hans Lellelid <hans@xmpl.org>
  * @package  phing.tasks.ext
- * @version  $Id: e35435d78a6eca384d1c6735565077868b265778 $
+ * @version  $Id: 11ecf61bf1d7f534232f2394df745ee147f2b9b7 $
  */
 class PearPackageTask extends MatchingTask
 {
@@ -154,7 +154,7 @@ class PearPackageTask extends MatchingTask
         // validation & return errors
         $e = $this->pkg->setOptions($this->preparedOptions);
 
-        if (PEAR::isError($e)) {
+        if (@PEAR::isError($e)) {
             throw new BuildException("Unable to set options.", new Exception($e->getMessage()));
         }
 
@@ -241,7 +241,7 @@ class PearPackageTask extends MatchingTask
         $this->setOptions();
 
         $e = $this->pkg->writePackageFile();
-        if (PEAR::isError($e)) {
+        if (@PEAR::isError($e)) {
             throw new BuildException("Unable to write package file.", new Exception($e->getMessage()));
         }
 
