@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: b578933a358450388983cfadb588d5366df88f20 $
+ *  $Id: b0540d6f531fdc2a5103a09c92a54318ebdf8c0b $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -49,7 +49,7 @@ include_once 'phing/system/io/StringReader.php';
  * @author    Michael McCallum <gholam@xtra.co.nz> (Ant)
  * @author    Tim Stephenson <tim.stephenson@sybase.com> (Ant)
  * @package   phing.tasks.ext.creole
- * @version   $Id: b578933a358450388983cfadb588d5366df88f20 $
+ * @version   $Id: b0540d6f531fdc2a5103a09c92a54318ebdf8c0b $
  */
 class CreoleSQLExecTask extends CreoleTask
 {
@@ -215,7 +215,7 @@ class CreoleSQLExecTask extends CreoleTask
 
     /**
      * Set the Delimiter type for this sql task. The delimiter type takes two
-     * values - normal and row. Normal means that any occurence of the delimiter
+     * values - normal and row. Normal means that any occurrence of the delimiter
      * terminate the SQL command whereas with row, only a line containing just
      * the delimiter is recognized as the end of the command.
      *
@@ -348,7 +348,7 @@ class CreoleSQLExecTask extends CreoleTask
                     for ($i = 0, $size = count($this->transactions); $i < $size; $i++) {
                         $this->transactions[$i]->runTransaction($out);
                         if (!$this->isAutocommit()) {
-                            $this->log("Commiting transaction", Project::MSG_VERBOSE);
+                            $this->log("Committing transaction", Project::MSG_VERBOSE);
                             $this->conn->commit();
                         }
                     }
