@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 2800e23b0fecfddc209dec5c7985e0c8eace0959 $
+ *  $Id: 4a3c05035ee7d8e1b9c019e218eaa84cf6979df8 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ require_once 'phing/tasks/ext/dbdeploy/DbmsSyntaxFactory.php';
  *     userid="dbdeploy" password="dbdeploy" dir="db" outputfile="">
  *
  * @author   Luke Crouch at SourceForge (http://sourceforge.net)
- * @version  $Id: 2800e23b0fecfddc209dec5c7985e0c8eace0959 $
+ * @version  $Id: 4a3c05035ee7d8e1b9c019e218eaa84cf6979df8 $
  * @package  phing.tasks.ext.dbdeploy
  */
 class DbDeployTask extends Task
@@ -255,6 +255,12 @@ class DbDeployTask extends Task
                 $fullFileName = $this->dir . '/' . $fileName;
                 $fh = fopen($fullFileName, 'r');
                 $contents = fread($fh, filesize($fullFileName));
+                $count_bad_comments = substr_count($contents, '--//');
+                if ($count_bad_comments > 0) {
+                    $this->log('Your SQL delta includes "--//" which, if a comment, should be replaced with "-- //"
+                    to avoid the delta failing.  You may need to manually undo part of this delta.\n\n'
+                        . $contents, Project::MSG_WARN);
+                }
                 // allow construct with and without space added
                 $split = strpos($contents, '-- //@UNDO');
                 if ($split === false) {
