@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 0eb5ad0732bc3acd74df7f9256b37952ddce3212 $
+ *  $Id: dd752b7e037caa7f88161c886585b8350be1a94d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -25,7 +25,7 @@ require_once 'phing/tasks/ext/git/GitBaseTask.php';
  * Wrapper around git-checkout
  *
  * @author Victor Farazdagi <simple.square@gmail.com>
- * @version $Id: 0eb5ad0732bc3acd74df7f9256b37952ddce3212 $
+ * @version $Id: dd752b7e037caa7f88161c886585b8350be1a94d $
  * @package phing.tasks.ext.git
  * @see VersionControl_Git
  * @since 2.4.3
@@ -125,7 +125,7 @@ class GitCheckoutTask extends GitBaseTask
             sprintf('git-checkout: checkout "%s" repository', $this->getRepository()),
             Project::MSG_INFO
         );
-        $this->log('git-checkout output: ' . trim($output), Project::MSG_INFO);
+        $this->log('git-checkout output: ' . str_replace('\'', '', trim($output)), Project::MSG_INFO);
     }
 
     /**
