@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 38e14c1e65c40c92325fa4729829d0948ba2791c $
+ *  $Id: 9f22f2863b649ddf3820399fd5738c58900b3a24 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -24,7 +24,7 @@
  * PHP 5.2 compatibility in the main task)
  *
  * @author    Michiel Rook <mrook@php.net>
- * @version   $Id: 38e14c1e65c40c92325fa4729829d0948ba2791c $
+ * @version   $Id: 9f22f2863b649ddf3820399fd5738c58900b3a24 $
  * @since     2.4.10
  * @package   phing.tasks.ext.phpdoc
  */
@@ -72,6 +72,12 @@ class PhpDocumentor2Wrapper
      */
     private $phpDocumentorPath = "";
 
+    /**
+     * Path to the phpDocumentor .phar
+     * @var string
+     */
+    private $pharLocation = '';
+
     /**
      * @var \phpDocumentor\Application
      */
@@ -133,21 +139,38 @@ class PhpDocumentor2Wrapper
         $this->defaultPackageName = (string) $defaultPackageName;
     }
 
+    /**
+     * @param string $pharLocation
+     */
+    public function setPharLocation($pharLocation)
+    {
+        $this->pharLocation = $pharLocation;
+    }
+
     /**
      * Finds and initializes the phpDocumentor installation
      */
     private function initializePhpDocumentor()
     {
-        if (class_exists('Composer\\Autoload\\ClassLoader', false)) {
+        $phpDocumentorPath = '';
+
+        if (!empty($this->pharLocation)) {
+            include_once 'phar://' . $this->pharLocation . '/vendor/autoload.php';
+
             if (!class_exists('phpDocumentor\\Bootstrap')) {
-                throw new BuildException('You need to install PhpDocumentor 2 or add your include path to your composer installation.');
+                throw new BuildException(
+                    $this->pharLocation . ' does not look like a phpDocumentor 2 .phar'
+                );
+            }
+        } elseif (class_exists('Composer\\Autoload\\ClassLoader', false)) {
+            if (!class_exists('phpDocumentor\\Bootstrap')) {
+                throw new BuildException('You need to install phpDocumentor 2 or add your include path to your composer installation.');
             }
-            $phpDocumentorPath = '';
         } else {
             $phpDocumentorPath = $this->findPhpDocumentorPath();
 
             if (empty($phpDocumentorPath)) {
-                throw new BuildException("Please make sure PhpDocumentor 2 is installed and on the include_path.");
+                throw new BuildException("Please make sure phpDocumentor 2 is installed and on the include_path.");
             }
 
             set_include_path($phpDocumentorPath . PATH_SEPARATOR . get_include_path());
