@@ -1,6 +1,6 @@
 <?php
 /**
- *  $Id: b0905525e212075bd1c6837036a718223a77395c $
+ *  $Id: 6de5c80e97545cd52494c53490e96c09aa61e703 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -28,7 +28,7 @@ require_once 'phing/tasks/ext/phpmd/PHPMDFormatterElement.php';
  *
  * @package phing.tasks.ext.phpmd
  * @author  Benjamin Schultz <bschultz@proqrent.de>
- * @version $Id: b0905525e212075bd1c6837036a718223a77395c $
+ * @version $Id: 6de5c80e97545cd52494c53490e96c09aa61e703 $
  * @since   2.4.1
  */
 class PHPMDTask extends Task
@@ -99,6 +99,13 @@ class PHPMDTask extends Task
      */
     protected $pharLocation = "";
 
+    /**
+     * Cache data storage
+     *
+     * @var DataStore
+     */
+    protected $cache;
+
     /**
      * Set the input source file or directory.
      *
@@ -204,6 +211,16 @@ class PHPMDTask extends Task
         $this->pharLocation = $pharLocation;
     }
 
+    /**
+     * Whether to store last-modified times in cache
+     *
+     * @param PhingFile $file
+     */
+    public function setCacheFile(PhingFile $file)
+    {
+        $this->cache = new DataStore($file);
+    }
+
     /**
      * Find PHPMD
      *
@@ -232,8 +249,9 @@ class PHPMDTask extends Task
         }
 
         if ($this->newVersion) {
-            //weird syntax to allow 5.2 parser compatability
+            //weird syntax to allow 5.2 parser compatibility
             $minPriority = constant('\PHPMD\AbstractRule::LOWEST_PRIORITY');
+            require_once 'phing/tasks/ext/phpmd/PHPMDRendererRemoveFromCache.php';
         } else {
             require_once 'PHP/PMD/AbstractRule.php';
             $minPriority = PHP_PMD_AbstractRule::LOWEST_PRIORITY;
@@ -246,6 +264,39 @@ class PHPMDTask extends Task
         return $className;
     }
 
+    /**
+     * Return the list of files to parse
+     *
+     * @return string[] list of absolute files to parse
+     */
+    protected function getFilesToParse()
+    {
+        $filesToParse = array();
+
+        if ($this->file instanceof PhingFile) {
+            $filesToParse[] = $this->file->getPath();
+        } else {
+            // append any files in filesets
+            foreach ($this->filesets as $fs) {
+                $dir = $fs->getDir($this->project)->getAbsolutePath();
+                foreach ($fs->getDirectoryScanner($this->project)->getIncludedFiles() as $filename) {
+                    $fileAbsolutePath = $dir . DIRECTORY_SEPARATOR . $filename;
+                    if ($this->cache) {
+                        $lastMTime = $this->cache->get($fileAbsolutePath);
+                        $currentMTime = filemtime($fileAbsolutePath);
+                        if ($lastMTime >= $currentMTime) {
+                            continue;
+                        } else {
+                            $this->cache->put($fileAbsolutePath, $currentMTime);
+                        }
+                    }
+                    $filesToParse[] = $fileAbsolutePath;
+                }
+            }
+        }
+        return $filesToParse;
+    }
+
     /**
      * Executes PHPMD against PhingFile or a FileSet
      *
@@ -282,36 +333,33 @@ class PHPMDTask extends Task
             $reportRenderers[] = $fe->getRenderer();
         }
 
+        if ($this->newVersion && $this->cache) {
+            $reportRenderers[] = new PHPMDRendererRemoveFromCache($this->cache);
+        } else {
+            $this->cache = null; // cache not compatible to old version
+        }
+
         // Create a rule set factory
         if ($this->newVersion) {
             $ruleSetClass = '\PHPMD\RuleSetFactory';
-            $ruleSetFactory = new $ruleSetClass(); //php 5.2 parser compatability
+            $ruleSetFactory = new $ruleSetClass(); //php 5.2 parser compatibility
 
         } else {
             if (!class_exists("PHP_PMD_RuleSetFactory")) {
-                @include 'PHP/PMD/RuleSetFactory.php';
+                    @include 'PHP/PMD/RuleSetFactory.php';
             }
             $ruleSetFactory = new PHP_PMD_RuleSetFactory();
         }
         $ruleSetFactory->setMinimumPriority($this->minimumPriority);
 
+        /**
+         * @var PHPMD\PHPMD $phpmd
+         */
         $phpmd = new $className();
         $phpmd->setFileExtensions($this->allowedFileExtensions);
         $phpmd->setIgnorePattern($this->ignorePatterns);
 
-        $filesToParse = array();
-
-        if ($this->file instanceof PhingFile) {
-            $filesToParse[] = $this->file->getPath();
-        } else {
-            // append any files in filesets
-            foreach ($this->filesets as $fs) {
-                foreach ($fs->getDirectoryScanner($this->project)->getIncludedFiles() as $filename) {
-                    $f = new PhingFile($fs->getDir($this->project), $filename);
-                    $filesToParse[] = $f->getAbsolutePath();
-                }
-            }
-        }
+        $filesToParse = $this->getFilesToParse();
 
         if (count($filesToParse) > 0) {
             $inputPath = implode(',', $filesToParse);
@@ -320,6 +368,10 @@ class PHPMDTask extends Task
 
             $phpmd->processFiles($inputPath, $this->rulesets, $reportRenderers, $ruleSetFactory);
 
+            if ($this->cache) {
+                $this->cache->commit();
+            }
+
             $this->log('Finished processing files');
         } else {
             $this->log('No files to process');
