@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: d3d7f451134334520e03ba410d4e3ddd5beb1bfe $
+ *  $Id: 589bdc7bd8655c49d96748d54990ba0bf6a8f0b1 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -29,7 +29,7 @@ include_once 'phing/util/StringHelper.php';
  *
  * @author Hans Lellelid <hans@xmpl.org> (Phing)
  * @author Jeff Martin <jeff@custommonkey.org> (Ant)
- * @version $Id: d3d7f451134334520e03ba410d4e3ddd5beb1bfe $
+ * @version $Id: 589bdc7bd8655c49d96748d54990ba0bf6a8f0b1 $
  * @package phing.tasks.system
  */
 class CvsPassTask extends Task
@@ -387,11 +387,11 @@ class CvsPassTask extends Task
      * @param $password
      * @return string
      */
-    final private function mangle($password)
+    private function mangle($password)
     {
         $buf = "";
         for ($i = 0, $plen = strlen($password); $i < $plen; $i++) {
-            $buf .= chr(self::$shifts[ord($password{$i})]);
+            $buf .= chr(self::$shifts[ord($password[$i])]);
         }
 
         return $buf;
