@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 98f1ceac9bbf413fc3986dfaf4fc7a63f8217b70 $
+ *  $Id: 05920a66ee560b0a27c61fe27a8703df9424ec16 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -41,7 +41,7 @@ require_once 'phing/Task.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: 98f1ceac9bbf413fc3986dfaf4fc7a63f8217b70 $
+ * @version   $Id: 05920a66ee560b0a27c61fe27a8703df9424ec16 $
  * @package   phing.tasks.system
  */
 class PhingCallTask extends Task
@@ -151,6 +151,10 @@ class PhingCallTask extends Task
      */
     public function main()
     {
+        if ($this->getOwningTarget()->getName() === "") {
+            $this->log("Cowardly refusing to call target '{$this->subTarget}' from the root", Project::MSG_WARN);
+            return;
+        }
 
         $this->log("Running PhingCallTask for target '" . $this->subTarget . "'", Project::MSG_DEBUG);
         if ($this->callee === null) {
