@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: e25b4d62e56e9dad7e7e776ef7214a9557e0f18d $
+ *  $Id: 5b75a9967dcec673581fb33340fbc00f51b1c6e8 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ include_once 'phing/system/io/FileParserFactory.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
- * @version   $Id: e25b4d62e56e9dad7e7e776ef7214a9557e0f18d $
+ * @version   $Id: 5b75a9967dcec673581fb33340fbc00f51b1c6e8 $
  * @package   phing.tasks.system
  */
 class PropertyTask extends Task
@@ -463,6 +463,10 @@ class PropertyTask extends Task
             // multiple passes.
 
             $value = $props->getProperty($name);
+            if (is_bool($value)) {
+                continue; // It's a boolean value, no need to resolve
+            }
+            
             $resolved = false;
             $resolveStack = array();
 
@@ -552,7 +556,7 @@ class PropertyTask extends Task
             if ($pos === (strlen($value) - 1)) {
                 array_push($fragments, '$');
                 $prev = $pos + 1;
-            } elseif ($value{$pos + 1} !== '{') {
+            } elseif ($value[$pos + 1] !== '{') {
 
                 // the string positions were changed to value-1 to correct
                 // a fatal error coming from function substring()
