@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 31e829a7d42bf922181a32e06d50057ab32afbbf $
+ *  $Id: 1e81905398152ad35f75d84e33e9e7c30c1547b3 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -43,7 +43,7 @@ class IsTrueCondition extends ProjectComponent implements Condition
      */
     public function setValue($value)
     {
-        $this->value = $value;
+        $this->value = (bool) $value;
     }
 
     /**
