@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 3580922ff080d58337586aca7d14d6d9ab5a02f0 $
+ *  $Id: d35bf0481e55f713cf67a71878d978f224baa05e $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -20,12 +20,15 @@
  */
 
 include_once 'phing/types/DataType.php';
+include_once 'phing/filters/ConcatFilter.php';
 include_once 'phing/filters/HeadFilter.php';
 include_once 'phing/filters/IconvFilter.php';
 include_once 'phing/filters/TailFilter.php';
 include_once 'phing/filters/LineContains.php';
 include_once 'phing/filters/LineContainsRegexp.php';
+include_once 'phing/filters/EscapeUnicode.php';
 include_once 'phing/filters/ExpandProperties.php';
+include_once 'phing/filters/PhpArrayMapLines.php';
 include_once 'phing/filters/PrefixLines.php';
 include_once 'phing/filters/ReplaceRegexp.php';
 include_once 'phing/filters/ReplaceTokens.php';
@@ -46,7 +49,7 @@ include_once 'phing/filters/XsltFilter.php';
  * FilterChain may contain a chained set of filter readers.
  *
  * @author    Yannick Lecaillez <yl@seasonfive.com>
- * @version   $Id: 3580922ff080d58337586aca7d14d6d9ab5a02f0 $
+ * @version   $Id: d35bf0481e55f713cf67a71878d978f224baa05e $
  * @package   phing.types
  */
 class FilterChain extends DataType
@@ -72,6 +75,15 @@ class FilterChain extends DataType
         return $this->filterReaders;
     }
 
+    /**
+     * @param ConcatFilter $o
+     */
+    public function addConcatFilter(ConcatFilter $o)
+    {
+        $o->setProject($this->project);
+        $this->filterReaders[] = $o;
+    }
+
     /**
      * @param ExpandProperties $o
      */
@@ -153,6 +165,24 @@ class FilterChain extends DataType
         $this->filterReaders[] = $o;
     }
 
+    /**
+     * @param PrefixLines $o
+     */
+    public function addEscapeUnicode(EscapeUnicode $o)
+    {
+        $o->setProject($this->project);
+        $this->filterReaders[] = $o;
+    }
+
+    /**
+     * @param PhpArrayMapLines $o
+     */
+    public function addPhpArrayMapLines(PhpArrayMapLines $o)
+    {
+        $o->setProject($this->project);
+        $this->filterReaders[] = $o;
+    }
+
     /**
      * @param ReplaceTokens $o
      */
