@@ -3,7 +3,7 @@
 include_once 'phing/system/io/PhingFile.php';
 
 /**
- * $Id: c919335e2dde3109449d2a7a76e8700d77653d03 $
+ * $Id: 9f3deadd6a2b93620d27fe8959f9f688b4c58171 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -26,7 +26,7 @@ include_once 'phing/system/io/PhingFile.php';
  * Extended file stream wrapper class which auto-creates directories
  *
  * @author Michiel Rook <mrook@php.net>
- * @version $Id: c919335e2dde3109449d2a7a76e8700d77653d03 $
+ * @version $Id: 9f3deadd6a2b93620d27fe8959f9f688b4c58171 $
  * @package phing.util
  */
 class ExtendedFileStream
@@ -77,6 +77,10 @@ class ExtendedFileStream
 
         $this->fp = fopen($filepath, $mode);
 
+        if (! $this->fp) {
+            throw new BuildException("Unable to open stream for path {$path}");
+        }
+
         return true;
     }
 
