@@ -114,7 +114,7 @@ class PathTokenizer
         }
 
 
-        if (strlen($token) === 1 && Character::isLetter($token{0})
+        if (strlen($token) === 1 && Character::isLetter($token[0])
 
             && $this->dosStyleFilesystem
 
